${ title }

<%inherit file="../base/base.html" /> <%namespace file="../base/base.html" import="header, setup_margin_labels" /> <%block name="title_head"> <%block name="extra_meta"> % if print_promissory_note: % endif ${ setup_margin_labels(title) }
${ header(complete_header, title, subtitle, notes) }

${ _("Responsible") }: | ${ loan.responsible.person.name } | ${ _("Client") }: | ${ loan.client.person.name }
${ _("Branch") }: | ${ loan.branch.person.name } | ${ _("Removed by") }: | ${ loan.removed_by }
${ _("Opening date") }: | ${ format_date(loan.open_date) } | ${ _("Expiring date") }: | ${ format_date(loan.expire_date) }

${ _("Code") } | ${ _("Category") } | ${ _("Item") } | ${ _("Quantity") } | ${ _("Price") } | ${ _("Total") }
% for item in loan.get_items():
${ item.sellable.code } | ${ item.sellable.get_category_description() } | ${ item.sellable.get_description() } | ${ format_quantity(item.quantity) } | ${ format_price(item.price) } | ${ format_price(item.get_total()) }
% endfor
${ _("Total: %s") % format_price(loan.get_total_amount()) }

${ _("I inform and sign up to receive the items in full " "working order and I am aware of the responsability " "that I have for returning them, as well as the " "return of the amounts involved, in case of loss, " "damage or any event that make the product unusable.") }
${ loan.client.person.name }
% if loan.client.person.individual: % if loan.client.person.individual.rg_number: RG: ${ loan.client.person.individual.rg_number }
% endif % if loan.client.person.individual.cpf: CPF: ${ loan.client.person.individual.cpf }
% endif % elif loan.client.person.company: % if loan.client.person.company.cnpj: CNPJ: ${ loan.client.person.company.cnpj }
% endif % endif
% if print_promissory_note:
<%include file="../base/promissory-note.html" args="b=promissory_data" />
% endif